/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.extensions.cdi.core.api.scope.conversation.config;

import org.apache.myfaces.extensions.cdi.core.api.config.CodiConfig;

import java.io.Serializable;

/**
 * @author Gerhard Petracek
 */
public interface WindowContextConfig extends CodiConfig, Serializable
{
    /**
     * Specifies if it is allowed to use URL params for forwarding the current window-id.
     * (deactivate it e.g. for higher security - in this case it's required to use a window id provided by a
     * component lib or a server-side window-handler)
     * 
     * @return true if it is allowed to add the window-id as URL parameter
     */
    boolean isUrlParameterSupported();

    /**
     * Allows to restrict window-ids.
     * With the default window handler (esp. for JSF 1.2), URLs have to contain the window-id.
     * If users bookmark these links, they could open 2-n tabs (with the bookmark) which have the same window-id.
     * It isn't possible to prevent it if the session is still active, but it's possible to prevent it as soon as the
     * session gets closed.
     *
     * @return true to allow window-ids which aren't generated by CODI, false otherwise
     */
    boolean isUnknownWindowIdsAllowed();

    /**
     * if set to <code>true</code> CODI will add a windowId=xxx parameter
     * while encoding each action URL.
     */
    @Deprecated
    boolean isAddWindowIdToActionUrlsEnabled();

    /**
     * Specifies the time for the timeout for a window. After a timeout is detected all beans which are only linked
     * to the window will be destroyed.
     *
     * @return the time for the timeout for a window
     */
    int getWindowContextTimeoutInMinutes();

    /**
     * Restricts the number of active windows.
     *
     * @return limit for active windows
     */
    int getMaxWindowContextCount();

    /**
     * Allows to activate the cleanup of empty window contexts to avoid cleanup e.g.
     * of the eldest window context instances if the max. count is reached.
     *
     * @return true for activating it, false otherwise
     */
    boolean isCloseEmptyWindowContextsEnabled();
    
    /*
     * event config
     */

    boolean isCreateWindowContextEventEnabled();

    boolean isCloseWindowContextEventEnabled();

    //boolean isResetWindowContextEventEnable();
}
